#!/usr/bin/env python


from affine import Affine   # noqa
from osgeo import ogr, osr   # noqa
import re   # noqa
import sys   # noqa

m_per_km = 1000.
resolutions = ["25", "12.5", "6.25", "3.125"]


class Ease2Transform():
    """
    The Ease2Transform class provides map projection conversion routines
    for geographic (lat/lon), grid (row/col), and map (x,y) locations in
    EASE-Grid 2.0 projections.

    2016-02-27 M. J. Brodzik brodzik@nsidc.org 303-492-8263
    National Snow & Ice Data Center, Boulder CO
    Copyright (C) 2016 Regents of the University of Colorado at Boulder
    """
    gridname = None
    epsg4326Proj4text = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"

    def __init__(self, gridname=None, verbose=False):
        """
        cetbtools.ease2conv.EASE2Transform(gridname)

        Returns a Transform object for the specified gridname.

        Parameters: gridname : string
                        EASE-Grid 2.0 gridname, following the pattern:
                        "EASE2-<proj><res>km", where:
                        <proj> is "N", "S" or "T"
                        <res> is "25", "12.5", "6.25" or "3.125"
                    verbose: bool, optional
                        If set to True, write verbose output to stderr

        Returns: initialized transformer for gridname

        Example:

        from cetbtools.ease2conv import Ease2Transform
        N25grid = Ease2Transform("EASE2_N25km")

        """
        self.gridname = gridname
        g = re.match(r'(EASE2_[NST])([0-9\.]+)km', gridname)
        if g is None:
            print("%s : error parsing gridname %s" % (__name__, gridname),
                  file=sys.stderr,
                  flush=True)
            raise ValueError
        projection = g.group(1)
        resolution = g.group(2)

        # Check for typos in resolution
        if resolution not in resolutions:
            print("%s : unrecognized resolution %s" % (__name__, resolution),
                  file=sys.stderr,
                  flush=True)
            raise ValueError

        # The geotransform information
        # is the set of GDAL affine transform parameters:
        # (map_UL_x, scale_x, b, map_UL_y, d, scale_y)
        if projection == "EASE2_N":
            # The geotransform is the set of GDAL affine transform parameters:
            # (map_UL_x, scale_x, b, map_UL_y, d, scale_y)
            self.proj4text = "+proj=laea +lat_0=90 +lon_0=0 " + \
                "+x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m"
            self.map_UL_x = -9000000.
            self.map_UL_y = 9000000.
            self.b = 0.
            self.d = 0.
            self.scale_x = float(resolution) * m_per_km
            self.scale_y = -1 * float(resolution) * m_per_km

        elif projection == "EASE2_S":
            self.proj4text = "+proj=laea +lat_0=-90 +lon_0=0 " + \
                "+x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m"
            self.map_UL_x = -9000000.
            self.map_UL_y = 9000000.
            self.b = 0.
            self.d = 0.
            self.scale_x = float(resolution) * m_per_km
            self.scale_y = -1 * float(resolution) * m_per_km

        elif projection == "EASE2_T":
            self.proj4text = "+proj=cea +lat_0=0 +lon_0=0 +lat_ts=30 " \
                "+x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m"
            self.map_UL_x = -17367530.44
            self.map_UL_y = 6756820.20000
            self.b = 0.
            self.d = 0.
            base_resolution_m = 25025.26000
            factor = resolutions.index(resolution)
            self.scale_x = base_resolution_m / (2. ** factor)
            self.scale_y = -1 * base_resolution_m / (2. ** factor)

        else:
            print("%s : unrecognized projection %s" % (__name__, projection),
                  file=sys.stderr,
                  flush=True)
            raise ValueError

        # Thanks to affine help pages at
        # https://github.com/sgillies/affine/blob/master/README.rst
        # http://www.perrygeo.com/python-affine-transforms.html
        geotransform = (self.map_UL_x + self.scale_x / 2.,
                        self.scale_x,
                        self.b,
                        self.map_UL_y + self.scale_y / 2.,
                        self.d,
                        self.scale_y)
        self.fwd = Affine.from_gdal(*geotransform)

        # Initialize and save coordinate transformation
        # for this projection
        self.gridSpatialRef = osr.SpatialReference()
        self.gridSpatialRef.SetFromUserInput(self.proj4text)

        # Initialize and save coordinate transformation
        # for EPSG4326 (lat/lon)
        self.epsg4326SpatialRef = osr.SpatialReference()
        self.epsg4326SpatialRef.SetFromUserInput(self.epsg4326Proj4text)

        # Initialize and save the forward and reverse transformations
        self.projToGeog = osr.CoordinateTransformation(
            self.gridSpatialRef, self.epsg4326SpatialRef)
        self.geogToProj = osr.CoordinateTransformation(
            self.epsg4326SpatialRef, self.gridSpatialRef)

        if verbose:
            print("%s : initialized new Ease2Transform object" % (__name__),
                  file=sys.stderr,
                  flush=True)

    def grid_to_map(self, row, col):
        """
        cetbtools.ease2conv.Ease2Transform.grid_to_map(row, col)

        Parameters: row, col : scalars
                        grid locations to convert, grid origin defined as
                        (row, col) = (0., 0.) at center of UL grid cell

        Returns: (x, y) map coordinates in meters

        Example:

        from cetbtools.ease2conv import Ease2Transform

        N25grid = Ease2Transform("EASE2_N25km")
        (x, y) = N25grid.grid_to_map(-0.5, -0.5)

        Returns (x, y) = (-9000000., 9000000), UL corner of UL cell

        """
        ax, ay = self.fwd * (col, row)

        return (ax, ay)

    def grid_to_geographic(self, row, col):
        """
        cetbtools.ease2conv.Ease2Transform.grid_to_geographic(row, col)

        Parameters: row, col : scalars
                        grid locations to convert, grid origin defined as
                        (row, col) = (0., 0.) at center of UL grid cell

        Returns: (lat, lon) geographic coordinates in degrees

        Example:

        from cetbtools.ease2conv import Ease2Transform

        N25grid = Ease2Transform("EASE2_N25km")
        (lat, lon) = N25grid.grid_to_geographic(359.5, 359.5)

        Returns (lat, lon) = (90., 0.), North pole

        """
        # Get map coordinates of row, col
        x, y = self.grid_to_map(row, col)

        # Create a geometry with the map coordinates
        point = ogr.Geometry(ogr.wkbPoint)
        point.AddPoint(x, y)

        point.Transform(self.projToGeog)

        return (point.GetY(), point.GetX())

    def map_to_grid(self, x, y):
        """
        cetbtools.ease2conv.Ease2Transform.map_to_grid(x, y)

        Parameters: x, y : scalars
                        map locations (in meters) to convert

        Returns: (row, col) grid coordinates, grid origin defined as
                        (row, col) = (0., 0.) at center of UL grid cell

        Example:

        from cetbtools.ease2conv import Ease2Transform

        N25grid = Ease2Transform("EASE2_N25km")
        (row, col) = N25grid.map_to_grid(-9000000., 9000000.)

        Returns (row, col) = (-0.5, -0.5), UL corner of UL cell

        """
        col, row = ~self.fwd * (x, y)

        return (row, col)

    def geographic_to_grid(self, lat, lon):
        """
        cetbtools.ease2conv.Ease2Transform.geographic_to_grid(lat, lon)

        Parameters: lat, lon : scalars
                        geographic coordinates (in degrees) to convert

        Returns: (row, col) converted grid location, grid origin defined as
                        (row, col) = (0., 0.) at center of UL grid cell

        Example:

        from cetbtools.ease2conv import Ease2Transform

        N25grid = Ease2Transform("EASE2_N25km")
        (row, col) = N25grid.geographic_to_grid(90., 0.)

        Returns (row, col) = (359.5, 359.5), grid location of North pole

        """
        # Create a geometry with the geographic coordinates
        point = ogr.Geometry(ogr.wkbPoint)
        point.AddPoint(lon, lat)

        point.Transform(self.geogToProj)

        # Returned values are in meters, convert to grid
        row, col = self.map_to_grid(point.GetX(), point.GetY())

        return (row, col)



import datetime

import requests
from swepy.nsidcDownloader import nsidcDownloader
import numpy as np
from netCDF4 import Dataset
from skimage.measure import block_reduce

from mapboxgl.utils import *
from mapboxgl.viz import *

import pandas as pd
from swepy.Ease2Transform import Ease2Transform
from nco import Nco
import os
from tqdm import tqdm
nco = Nco()

class swepy():
    '''Class Members'''
    def __init__(self, working_dir, start, end, ul, lr,
                outfile19 = 'all_days_19H.nc', outfile37 = 'all_days_37H.nc',
                username = 'wino6687', password = 'Desmo12@'):
        '''User instantiates the class with working directory,
        date ranges, and lat/lon bounding coords. constructor gets
        the datetime list, x/y coords, and file directories'''
        self.working_dir = working_dir
        self.path19, self.path37, self.wget = self.get_directories(working_dir)

        self.outfile_19 = outfile19
        self.outfile_37 = outfile37

        self.username = username
        self.password = password

        self.dates = pd.date_range(start, end)
        self.geo_list = self.get_xy(ul, lr)

        self.down19list = []
        self.down37list = []
        self.sub19list = []
        self.sub37list = []

        self.nD = nsidcDownloader.nsidcDownloader(folder = self.wget, username = username, password = password)
        self.N3 = Ease2Transform.Ease2Transform("EASE2_N3.125km")

    def get_directories(self, path):
        os.chdir(path)
        wget = path + "/data/wget/"
        path19 = path + "/data/Subsetted_19H/"
        path37 = path + "/data/Subsetted_37H/"

        if not os.path.exists(wget):
            os.makedirs(wget)
        if not os.path.exists(path19):
            os.makedirs(path19)
        if not os.path.exists(path37):
            os.makedirs(path37)
        return path19, path37, wget


    def get_xy(self, ll_ul, ll_lr):
        '''Use NSIDC scripts to convert user inputted
        lat/lon into Ease grid 2.0 coordinates'''
        # get x,y for 3.125
        row, col = self.N3.geographic_to_grid(ll_ul[0], ll_ul[1])
        xul, yul = self.N3.grid_to_map(row, col)
        row, col = self.N3.geographic_to_grid(ll_lr[0], ll_lr[1])
        xlr, ylr = self.N3.grid_to_map(row, col)
        geo_list = [xul, yul, xlr, ylr]
        return geo_list


    def subset(self, scrape = False):
        '''pass geo-coord list and directory path
        script will get the files from wget directory
        and subset them geographically'''
        os.chdir(self.wget)
        for file in tqdm(self.down19list):
            outfile = self.path19 + file
            infile = self.wget + file
            opt = [
                "-d x,%f,%f" % (self.geo_list[0],self.geo_list[2]),
                "-d y,%f,%f" % (self.geo_list[3],self.geo_list[1]),
                "-v TB"
            ]
            nco.ncks(input=infile, output=outfile, options=opt)
            self.sub19list.append(outfile)
            os.remove(infile)

        for file in tqdm(self.down37list):
            outfile = self.path37 + file
            infile = self.wget + file
            opt = [
                "-d x,%f,%f" % (self.geo_list[0],self.geo_list[2]),
                "-d y,%f,%f" % (self.geo_list[3],self.geo_list[1]),
                "-v TB"
            ]
            nco.ncks(input=infile, output=outfile, options=opt)
            self.sub37list.append(outfile)
            os.remove(infile)
        # Empty the download lists
        self.down19list = []
        self.down37list = []
        return

    def scrape_all(self):
        '''Function to ensure we subset
         and concatenate every year!
         Implements the whole workflow!'''
        outfile19 = 'all_days_19H.nc'
        outfile37 = 'all_days_37H.nc'
        if len(self.dates) <= 133:
            for date in self.dates:
                file19 = self.get_file(date, "19H")
                file37 = self.get_file(date, "37H")
                self.down19list.append(self.nD.download_file(**file19))
                self.down37list.append(self.nD.download_file(**file37))
            self.subset()
            return self.concatenate()
        else:
            comp_list = [self.dates[x:x + 100] for x in range(0, len(self.dates), 100)]
            for count, subList in enumerate(comp_list):
                tempfile19 = '19H' + str(count) + 'temp.nc'
                tempfile37 = '37H' + str(count) + 'temp.nc'
                for date in subList:
                    file19 = get_file(date, "19H")
                    file37 = get_file(date, "37H")
                    self.down19list.append(self.nD.download_file(**file19))
                    self.down37list.append(self.nD.download_file(**file37))
                self.subset()
                #concatenate(self, tempfile19, tempfile37)
            return self.concatenate()


    def get_file(self, date, channel): # add more defaulting params
        '''Function that uses date and channel to
        find optimal file composition and return the
        file params for the web scraper's use.'''
        sensors = {1992: 'F11', 1993: 'F11', 1994: 'F11', 1995: 'F11', 1996: 'F13', 1997: 'F13', 1998: 'F13',
                1999: 'F13', 2000: 'F13', 2001: 'F13', 2002: 'F13', 2003: 'F15', 2004: 'F15', 2005: 'F15', 2006: 'F15',
                2007: 'F15', 2008: 'F16', 2009: 'F17', 2010: 'F17', 2011: 'F17', 2012: 'F17', 2013: 'F17', 2014: 'F18',
                2015: 'F19'}
        ssmi_s = "SSMIS" if sensors[date.year] in ['F16', 'F17', 'F18', 'F19'] else "SSMI"
        resolution = '6.25km' if channel == '19H' else '3.125km'
        file = {
            "resolution": resolution,
            "platform": sensors[date.year],
            "sensor": ssmi_s,
            "date": date,
            "channel": channel,
            "dataversion": 'v1.3' if date.year == 2015 else 'v1.2'
        }
        return file

    ## use list of paths as parameter to concatenate all paths in list
    ## ['/folder/file1.nc','/folder/file2.nc']
    def concatenate(self, subset = False):
        '''Function to concatenate files in the subsetted data
        folders. Takes working directory path, the desired outfile
        names, and whether or not this is a final pass in the subet_all
        function as input.'''
        os.chdir(self.path19)
        # Concatenate 19GHz files:
        if len(self.sub19list) != 0:
            nco.ncrcat(input=self.sub19list, output = self.outfile_19, options=["-O"])
        else:
            print("No 19Ghz Files to Concatenate")
        # Concatenate 37GHz files:
        os.chdir(self.path37) # do i want to do this now? could put them somewhere else?
        if len(self.sub37list) != 0:
            nco.ncrcat(input = self.sub37list, output = self.outfile_37, options = ["-O"])
        else:
            print("No 37Ghz Files to Concatenate")

        self.clear_sub_files() # clean out files that were concat

        return self.outfile_19, self.outfile_37


    def clear_sub_files(self):
        os.chdir(self.path19)
        filelist = glob.glob('NSIDC*')
        for f in filelist:
            os.remove(f)
        os.chdir(self.path37)
        filelist = glob.glob('NSIDC*')
        for f in filelist:
            os.remove(f)
        return


    def scrape(self):
        '''Wrapper function to allow more selective use of just the
            web scraper'''
        for date in self.dates:
            file19 = self.get_file(date, "19H")
            file37 = self.get_file(date, "37H")
            self.down19list.append(self.nD.download_file(**file19))
            self.down37list.append(self.nD.download_file(**file37))
        return





def plot_a_day(file1, file2, path, token):
    '''read tb,x,y data from final files,
    with the purpose of plotting.'''
    os.chdir(path + '/data/Subsetted_19H')
    fid_19H = Dataset(file1, "r", format="NETCDF4")
    os.chdir(path + '/data/Subsetted_37H')
    fid_37H = Dataset(file2, "r", format="NETCDF4")
    x = fid_19H.variables['x'][:]
    y = fid_37H.variables['y'][:]
    tb_19H = fid_19H.variables['TB'][:]
    tb_37H = fid_37H.variables['TB'][:]
    tb_37H = block_reduce(tb_37H, block_size = (1,2,2), func = np.mean)
    tb= tb_19H  - tb_37H
    lats = np.zeros((len(y), len(x)), dtype=np.float64)
    lons = np.zeros((len(y), len(x)), dtype=np.float64)
    grid = e2.Ease2Transform(gridname=fid_19H.variables["crs"].long_name)
    for i, xi in enumerate(x):
        for j, yj in enumerate(y):
            row, col = grid.map_to_grid(xi, yj)
            lat, lon = grid.grid_to_geographic(row, col)
            lats[j, i] = lat
            lons[j, i] = lon
    one_day = tb[0,:,:]
    df = pd.DataFrame(columns = ['lat', 'lon', 'swe'])
    for i in range(len(one_day[:,1])):
        for j in range(len(one_day[1,:])):
            df = df.append({'lat': lats[i][j], 'lon': lons[i][j], 'swe':one_day[i][j]}, ignore_index = True)
    df_to_geojson(df, filename = 'swe_1day.geojson',properties = ['swe'],lat = 'lat', lon = 'lon')
    measure = 'swe'
    color_breaks = [round(df[measure].quantile(q=x*0.1), 2) for x in range(1,9)]
    color_stops = create_color_stops(color_breaks, colors='YlGnBu')

    # Create the viz from the dataframe
    viz = CircleViz('swe_1day.geojson',
                    access_token=token,
                    color_property = "swe",
                    color_stops = color_stops,
                    center = (-154, 67),
                    zoom = 3,
                    below_layer = 'waterway-label')

    viz.show()



#!/usr/bin/env python3

import os
import requests

from tqdm import tqdm
from datetime import datetime
from functools import partial
from string import Formatter

import pandas as pd

try:
    if get_ipython().config['IPKernelApp']['parent_appname'] == 'ipython-notebook':
        from tqdm import tqdm_notebook as tqdm
except:
    pass

class nsidcDownloader():

    url_template = "{protocol}://{server}/{datapool}/{dataset}.{version}/{date:%Y.%m.%d}" \
                    "/{dataset}-{projection}_{grid}{resolution}-{platform}_{sensor}" \
                    "-{date:%Y%j}-{channel}-{pass}-{algorithm}-{input}-{dataversion}.nc"

    defaults = {
        "protocol": "https",
        "server": "n5eil01u.ecs.nsidc.org",
        "datapool": "MEASURES",
        "dataset": "NSIDC-0630",
        "version": "001",
        "projection": "EASE2",
        "grid": "N",
        "pass": "M",
        "algorithm": "SIR",
        "input": "CSU",
        "dataversion": "v1.2"
    }

    def __init__(self, username=None, password=None, folder=".", **kwargs):
        '''
        Snow Water Equivalence downloader.

        :param username: NASA Earthdata username
        :param password: NASA Earthdata password
        :param kwargs: keys to use as default in url_template
        '''

        ## Get formatting keys of url_template
        self.url_keys = [k[1] for k in Formatter().parse(self.url_template)]

        ## Function to format URL
        self.format_url = partial(self.url_template.format)

        ## Set url template defaults to specified defaults
        self.set_defaults(**self.defaults) ## global defaults (in this class)
        self.set_defaults(**kwargs)        ## instance defaults

        ## Auth Detauls
        self.username = username
        self.password = password

        ## Tet up session
        self.session = requests.session()
        self.get_auth()

        ## Output
        self.folder = folder

    def set_defaults(self, **kwargs):
        '''
        Set defaults for url template
        '''

        for key in kwargs:
            if key in self.url_keys:
                self.format_url.keywords[key] = kwargs[key]

        return(self.format_url.keywords)

    def get_auth(self):
        '''
        Get download authentication

        How authentication works:
        (1) request to some sort of NSIDC URL
        (2) get HTTP 302 response redirecting to urs.earthdata.nasa.gov OAuth
        (3) login at urs.earthdata.nasa.gov oauth
        (4) use oauth tokens from urs.earthdata.nasa.gov to request any download url
        '''

        test_url = "{protocol}://{server}/SMAP/".format(**self.format_url.keywords)

        ## User / pass to use with auth.
        ## Will attempt to use auth in ~/.netrc if not passed
        if self.username and self.password:
            self.session.auth = (self.username, self.password)

        ## Send test request, keep following the redirects and scoop
        ## up all of the cookies along the way in self.session
        try:
            req = self.session.get(test_url, allow_redirects = False)

            while req.status_code == 302:
                req = self.session.get(req.headers["Location"],
                                       allow_redirects = False)
        except requests.ConnectionError:
            pass

        ## If the final request is 401 (Bad Auth), throw exception
        if req.status_code == 401:
            raise PermissionError("Bad NASA Earthdata Authentication!")

    def download_file(self, folder=None, overwrite=False, **kwargs):
        '''
        Download a file of particular kwargs
        '''

        url = self.format_url(**kwargs)

        ## Dict of all the keywords:vals going into URL
        all_keywords = {**kwargs, **self.format_url.keywords}

        ## Format output dir with keywords if there's none passed
        if not folder:
            folder = self.folder.format(all_keywords)

        ## Prepare file system
        filename = url.split("/")[-1]
        filepath = "{}/{}".format(folder, filename)
        block_size = 1024
        #print("{}".format(filename))

        if os.path.exists(filepath):
            if overwrite:
                os.remove(filepath)
            else:
                print(" ** (skipping...) **")
                return filename

        ## Download the dang thing
        with self.session.get(url, stream=True) as r:

            if r.status_code == 404:
                raise FileNotFoundError("File Not Found: {}".format(url))

            ## Open file
            with open(filepath, 'wb') as f:

                pbar = tqdm(initial=0,
                            total=int(r.headers['content-length']),
                            unit='B',
                            unit_scale=True)

                ## Create dest folder if not exist
                if not os.path.exists(folder):
                    os.makedirs(folder)

                ## Stream content to file in chunks
                for chunk in r.iter_content(block_size):
                    f.write(chunk)
                    pbar.update(block_size)

            pbar.close()

        return filename  ## changed to filename from filepath to fix another script

    def download_range(self, date, **kwargs):
        '''
        Download a range of dates for a particular sensor
        '''

        assert isinstance(date, list), "Range passed must be list of dates"

        for date in pd.date_range(date[0], date[1]):
            kwargs["date"] = date
            self.download_file(**kwargs)

#dl = nsidcDownloader(username="dale0007",
                     #="SnowWater1")

#dataset = {
    #"resolution": "3.125km",
    #"platform": "F17",
    #"sensor": "SSMIS",
    #"date": datetime(2015,10,10),
    #"channel": "37H"
#}



import datetime
import subprocess
import shlex
from subprocess import call
import pandas as pd
import ease2conv as e2
from nco import Nco
import os
from tqdm import tqdm
import glob
from swepy import swepy
import sys
nco = Nco()


print("\n\n\nScript for downloading, subsetting, and concatenating the data you want!\n")
try:
    lat_ul, lon_ul = input('Enter the upper left latitude,longitude \n(comma seperated <62.27, -140.17>): ').split(",")#[62.27, -140.17]
    lat_ul = str(lat_ul)
    lat_ul = lat_ul.replace(" ", "").strip()
    lon_ul = str(lon_ul)
    lon_ul = lon_ul.replace(" ", "").strip()
except:
    print("Wrong input type detected, using testing defaults")
    lon_ul = '-140'
    lat_ul = '62'
    #sys.exit(1)
try:
    lat_lr, lon_lr = input('\nEnter lower right latitude,longitude\n (comma seperated <73.64, -166.08>): ').split(",") #[73.64, -166.08]
    lat_lr = str(lat_lr)
    lat_lr = lat_lr.replace(" ", "").strip()
    lon_lr = str(lon_lr)
    lon_lr = lon_lr.replace(" ", "").strip()
except:
    print("Wrong input type detected, using testing defaults")
    lat_lr = '73'
    lon_lr = '-166'
    #sys.exit(1)
try:
    startY, startM, startD = input("\nEnter starting year, month, and day \n(comma seperated <2001, 5, 1>): ").split(",")
    startY = str(startY)
    startY = startY.replace(" ", "").strip()
    startM = str(startM)
    startM = startM.replace(" ", "").strip()
    startD = str(startD)
    startD = startD.replace(" ", "").strip()
except:
    print("Wrong input type detected, using testing defaults")
    startY = '2001'
    startM = '5'
    startD = '1'
    #sys.exit(1)
try:
    endY, endM, endD = input("\nEnter ending year, month, and day \n(comma seperated <2005, 10, 15>): ").split(",")
    endY = str(endY)
    endY = endY.replace(" ","").strip()
    endM = str(endM)
    endM = endM.replace(" ","").strip()
    endD = str(endD)
    endD = endD.replace(" ", "").strip()
except:
    print("Wrong input type detected, using testing defaults")
    endY = '2001'
    endM = '5'
    endD = '2'
    #sys.exit(1)

print(lat_ul, lon_ul, lat_lr, lon_lr, startY, startM, endY, endM)
ul = [float(lat_ul), float(lon_ul)]
lr = [float(lat_lr), float(lon_lr)]

start = datetime.date(int(startY), int(startM), int(startD))
end = datetime.date(int(endY), int(endM), int(endD))

path = os.getcwd()

swepy = swepy(path, start, end, ul, lr)

swepy.scrape_all()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="swepy",
    version="0.0.12",
    author="William Norris",
    author_email="wino6687@colorado.edu",
    description="A python package for obtaining and cleaning Tb files",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/wino6687/SWEpy",
    packages=setuptools.find_packages(),
    install_requires=[
    'datetime', 'numpy', 'netCDF4', 'scikit-image',
    'pandas', 'nco', 'os', 'tqdm', 'affine', 'requests',
    'GDAL', 'mapboxgl'
    ],
    classifiers=(
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ),
)
